import { IDocumentService } from './IDocumentService';
import { FileAddResult, ChunkedFileUploadProgressData, ListItemFormUpdateValue } from '@pnp/sp';
import { IFieldSchema } from './datatypes/RenderListData';
export declare class DocumentService implements IDocumentService {
    /**
     * Gets a file by server relative url
     *
     * @param fileRelativeUrl The server relative path to the file (including /sites/ if applicable)
     * @returns The new File and the raw response.
     */
    getFileFromListAsBlob(webUrl: string, fileRelativeUrl: string): Promise<Blob>;
    /**
     * Uploads a file. Not supported for batching
     * @param webUrl The absolute Url to the SharePoint site.
     * @param listName The name of the list the file will be uploaded to.
     * @param url The folder-relative url of the file.
     * @param content The Blob file content to add
     * @param progress A callback function which can be used to track the progress of the upload
     * @param shouldOverWrite Should a file with the same name in the same location be overwritten? (default: true)
     * @param chunkSize The size of each file slice, in bytes (default: 10485760)
     * @returns The new File and the raw response.
     */
    addFileBlob(webUrl: string, listName: string, url: string, content: Blob, progress?: (data: ChunkedFileUploadProgressData) => void, shouldOverwrite?: boolean, chunkSize?: number): Promise<FileAddResult>;
    /**
     * Saves the given data to the specified SharePoint list item.
     *
     * @param webUrl The absolute Url to the SharePoint site.
     * @param listUrl The server-relative Url to the SharePoint list.
     * @param stringId The UniqueId of the list item to be updated.
     * @param fieldsSchema The array of field schema for all relevant fields of this list.
     * @param data An object containing all the field values to update.
     * @param newDocumentUpdate true if the list item is a document being updated after upload; otherwise false.
     * @returns Promise object represents the updated or erroneous form field values.
     */
    updateItem(webUrl: string, listName: string, stringId: string, fieldsSchema: IFieldSchema[], data: any, newDocumentUpdate?: boolean): Promise<ListItemFormUpdateValue[]>;
    private GetFormValues;
    private getErrorMessage;
}
