"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var sp_1 = require("@pnp/sp");
var typescript_string_operations_1 = require("typescript-string-operations");
var DocumentService = /** @class */ (function () {
    function DocumentService() {
    }
    /**
     * Gets a file by server relative url
     *
     * @param fileRelativeUrl The server relative path to the file (including /sites/ if applicable)
     * @returns The new File and the raw response.
     */
    DocumentService.prototype.getFileFromListAsBlob = function (webUrl, fileRelativeUrl) {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
                        var web;
                        return __generator(this, function (_a) {
                            switch (_a.label) {
                                case 0:
                                    web = new sp_1.Web(webUrl);
                                    return [4 /*yield*/, web
                                            .getFileByServerRelativeUrl(fileRelativeUrl)
                                            .getBlob()
                                            .then(function (res) {
                                            resolve(res);
                                        })
                                            .catch(function (error) {
                                            reject(error);
                                        })];
                                case 1:
                                    _a.sent();
                                    return [2 /*return*/];
                            }
                        });
                    }); })];
            });
        });
    };
    /**
     * Uploads a file. Not supported for batching
     * @param webUrl The absolute Url to the SharePoint site.
     * @param listName The name of the list the file will be uploaded to.
     * @param url The folder-relative url of the file.
     * @param content The Blob file content to add
     * @param progress A callback function which can be used to track the progress of the upload
     * @param shouldOverWrite Should a file with the same name in the same location be overwritten? (default: true)
     * @param chunkSize The size of each file slice, in bytes (default: 10485760)
     * @returns The new File and the raw response.
     */
    DocumentService.prototype.addFileBlob = function (webUrl, listName, url, content, progress, shouldOverwrite, chunkSize) {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
                        var web;
                        var _this = this;
                        return __generator(this, function (_a) {
                            switch (_a.label) {
                                case 0:
                                    web = new sp_1.Web(webUrl);
                                    // large upload
                                    return [4 /*yield*/, web.lists
                                            .getByTitle(listName)
                                            .rootFolder.files.addChunked(url, content, progress, shouldOverwrite, chunkSize)
                                            .then(function (res) {
                                            resolve(res);
                                        })
                                            .catch(function (error) {
                                            reject(_this.getErrorMessage(webUrl, error));
                                        })];
                                case 1:
                                    // large upload
                                    _a.sent();
                                    return [2 /*return*/];
                            }
                        });
                    }); })];
            });
        });
    };
    /**
     * Saves the given data to the specified SharePoint list item.
     *
     * @param webUrl The absolute Url to the SharePoint site.
     * @param listUrl The server-relative Url to the SharePoint list.
     * @param stringId The UniqueId of the list item to be updated.
     * @param fieldsSchema The array of field schema for all relevant fields of this list.
     * @param data An object containing all the field values to update.
     * @param newDocumentUpdate true if the list item is a document being updated after upload; otherwise false.
     * @returns Promise object represents the updated or erroneous form field values.
     */
    DocumentService.prototype.updateItem = function (webUrl, listName, stringId, fieldsSchema, data, newDocumentUpdate) {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
                        var xml, values, camlQuery, web, list;
                        var _this = this;
                        return __generator(this, function (_a) {
                            switch (_a.label) {
                                case 0:
                                    xml = typescript_string_operations_1.String.Format(
                                    // tslint:disable-next-line:max-line-length
                                    '<View Scope=\'RecursiveAll\'><Query><Where><Eq><FieldRef Name=\'UniqueId\' /><Va' +
                                        'lue Type=\'Guid\'>{0}</Value></Eq></Where></Query></View>', stringId);
                                    values = this.GetFormValues(fieldsSchema, data);
                                    camlQuery = {
                                        ViewXml: xml
                                    };
                                    web = new sp_1.Web(webUrl);
                                    list = web.lists.getByTitle(listName);
                                    return [4 /*yield*/, list.getItemsByCAMLQuery(camlQuery).then(function (res) {
                                            list.items
                                                .getById(res[0].ID)
                                                .validateUpdateListItem(values, newDocumentUpdate)
                                                .then(function (respData) {
                                                resolve(respData);
                                            })
                                                .catch(function (error) {
                                                reject(_this.getErrorMessage(webUrl, error));
                                            });
                                        })];
                                case 1:
                                    _a.sent();
                                    return [2 /*return*/];
                            }
                        });
                    }); })];
            });
        });
    };
    DocumentService.prototype.GetFormValues = function (fieldsSchema, data) {
        return fieldsSchema
            .filter(function (field) { return !field.ReadOnlyField && field.InternalName in data && data[field.InternalName] !== null; })
            .map(function (field) {
            return {
                ErrorMessage: null,
                FieldName: field.InternalName,
                FieldValue: data[field.InternalName],
                HasException: false
            };
        });
    };
    DocumentService.prototype.getErrorMessage = function (webUrl, error) {
        var errorMessage = error.statusText
            ? error.statusText
            : error.statusMessage ? error.statusMessage : error;
        var serverUrl = "{window.location.protocol}//{window.location.hostname}";
        var webServerRelativeUrl = webUrl.replace(serverUrl, '');
        if (error.status === 403) {
            errorMessage = typescript_string_operations_1.String.Format(
            // tslint:disable-next-line:max-line-length
            'You do not have access to the previously configured web url \'{0}\'. Either leav' +
                'e the WebPart properties as is or select another web url.', webServerRelativeUrl);
        }
        else if (error.status === 404) {
            errorMessage = typescript_string_operations_1.String.Format(
            // tslint:disable-next-line:max-line-length
            'The previously configured web url \'{0}\' is not found anymore. Either leave the' +
                ' WebPart properties as is or select another web url.', webServerRelativeUrl);
        }
        return errorMessage;
    };
    return DocumentService;
}());
exports.DocumentService = DocumentService;
