import { ControlMode } from '../datatypes/ControlMode';
import { IFieldSchema, IField, IRowData } from './datatypes/RenderListData';
import { IListFormService } from './IListFormService';
export declare class ListFormService implements IListFormService {
    /**
     * Gets the schema for all relevant fields for a specified SharePoint list form.
     *
     * @param webUrl The absolute Url to the SharePoint site.
     * @param listUrl The server-relative Url to the SharePoint list.
     * @param viewId The type of form (Display, New, Edit)
     * @returns Promise object represents the array of field schema for all relevant fields for this list form.
     */
    getViewFields(webUrl: string, listName: string, viewId: string): Promise<IField[]>;
    /**
     * Gets the schema for all relevant fields for a specified SharePoint list form.
     *
     * @param webUrl The absolute Url to the SharePoint site.
     * @param listUrl The server-relative Url to the SharePoint list.
     * @param viewId The type of form (Display, New, Edit)
     * @returns Promise object represents the array of field schema for all relevant fields for this list form.
     */
    getViewItems(webUrl: string, listName: string, viewId: string, overrideParameters?: any, paging?: string): Promise<IRowData>;
    /**
     * Gets the schema for all relevant fields for a specified SharePoint list form.
     *
     * @param webUrl The absolute Url to the SharePoint site.
     * @param listName The name of the list.
     * @param formType The type of form (Display, New, Edit)
     * @returns Promise object represents the array of field schema for all relevant fields for this list form.
     */
    getFieldSchemasForForm(webUrl: string, listName: string, formType: ControlMode): Promise<IFieldSchema[]>;
    /**
     * Returns an error message based on the specified error object
     * @param error : An error string/object
     */
    private getErrorMessage;
}
