import { ITermStoreData, ITermStore, ITermSet, ITermData, ITerm, ITermSetData } from '@pnp/sp-taxonomy';
/**
 * Service implementation to manage term stores in SharePoint
 */
export default class SPTermStorePickerService {
    /**
     * Gets the collection of term stores for the provided Web Url.
     *
     * @param webUrl The absolute Url to the SharePoint site.
     * @returns Promise object represents the term store object.
     */
    getTermStores(webUrl: string): Promise<(ITermStoreData & ITermStore)[]>;
    /**
     * Gets the current term set
     *
     * @param webUrl The absolute Url to the SharePoint site.
     * @param termSetID The Term Set ID
     * @returns Promise object represents the the term set data.
     */
    getTermSet(webUrl: string, termSetID: string): Promise<ITermSetData & ITermSet>;
    /**
     * Retrieve all terms for the given term set
     * @param webUrl The absolute Url to the SharePoint site.
     * @param termSetID The Term Set ID
     * @returns Promise object represents the the term set data.
     */
    getAllTerms(webUrl: string, termSetNameOrID: string): Promise<(ITermData & ITerm)[]>;
    /**
     * Retrieve all terms that starts with the searchText
     * @param webUrl The absolute Url to the SharePoint site.
     * @param searchText The search term that text is returned by.
     * @returns Retrieve all terms for the given searchText
     */
    searchTermsByName(webUrl: string, searchText: string): Promise<(ITermData & ITerm)[]>;
    /**
     * Searches terms for the given term set
     * @param webUrl The absolute Url to the SharePoint site.
     * @param termSetID The Term Set ID
     * @param searchText The search term that text is returned by.
     * @returns Retrieve all terms for the given searchText in the Term Set ID.
     */
    searchTermsByTermSet(webUrl: string, termSetID: string, searchText: string): Promise<(ITermData & ITerm)[]>;
    private getErrorMessage;
}
