"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var ControlMode_1 = require("../common/datatypes/ControlMode");
var FormField_1 = require("./formFields/FormField");
var TextField_1 = require("office-ui-fabric-react/lib/TextField");
var Icon_1 = require("office-ui-fabric-react/lib/Icon");
var SPFieldTextEdit_1 = require("./formFields/SPFieldTextEdit");
var SPFieldLookupEdit_1 = require("./formFields/SPFieldLookupEdit");
var SPFieldChoiceEdit_1 = require("./formFields/SPFieldChoiceEdit");
var SPFieldNumberEdit_1 = require("./formFields/SPFieldNumberEdit");
var SPFieldDateEdit_1 = require("./formFields/SPFieldDateEdit");
var SPFieldBooleanEdit_1 = require("./formFields/SPFieldBooleanEdit");
var SPFieldTextDisplay_1 = require("./formFields/SPFieldTextDisplay");
var SPFieldLookupDisplay_1 = require("./formFields/SPFieldLookupDisplay");
var SPFieldUserDisplay_1 = require("./formFields/SPFieldUserDisplay");
var SPFieldUrlDisplay_1 = require("./formFields/SPFieldUrlDisplay");
require("./SPFormField.scss");
var SPFieldTaxonomyEdit_1 = require("./formFields/SPFieldTaxonomyEdit");
var SPUserEdit_1 = require("./formFields/SPUserEdit");
var styles = {
    dropDownFormField: 'dropDownFormField_e5e89a2f',
    dateFormField: 'dateFormField_e5e89a2f',
    unsupportedFieldMessage: 'unsupportedFieldMessage_e5e89a2f'
};
var EditFieldTypeMappings = {
    Text: SPFieldTextEdit_1.default,
    Note: SPFieldTextEdit_1.default,
    Lookup: SPFieldLookupEdit_1.default,
    LookupMulti: SPFieldLookupEdit_1.default,
    Choice: SPFieldChoiceEdit_1.default,
    MultiChoice: SPFieldChoiceEdit_1.default,
    Number: SPFieldNumberEdit_1.default,
    Currency: SPFieldNumberEdit_1.default,
    DateTime: SPFieldDateEdit_1.default,
    Boolean: SPFieldBooleanEdit_1.default,
    File: SPFieldTextEdit_1.default,
    TaxonomyFieldType: SPFieldTaxonomyEdit_1.default,
    TaxonomyFieldTypeMulti: SPFieldTaxonomyEdit_1.default,
    User: SPUserEdit_1.default,
    UserMulti: SPUserEdit_1.default
    /* The following are known but unsupported types as of now:

  URL: null,
  Attachments: null,
  */
};
var DisplayFieldTypeMappings = {
    Text: {
        component: SPFieldTextDisplay_1.default
    },
    Note: {
        component: SPFieldTextDisplay_1.default
    },
    Lookup: {
        component: SPFieldLookupDisplay_1.default
    },
    LookupMulti: {
        component: SPFieldLookupDisplay_1.default
    },
    Choice: {
        component: SPFieldTextDisplay_1.default
    },
    MultiChoice: {
        component: SPFieldTextDisplay_1.default,
        valuePreProcess: function (val) { return (val ? val.join(', ') : ''); }
    },
    Number: {
        component: SPFieldTextDisplay_1.default
    },
    Currency: {
        component: SPFieldTextDisplay_1.default
    },
    DateTime: {
        component: SPFieldTextDisplay_1.default
    },
    Boolean: {
        component: SPFieldTextDisplay_1.default
    },
    User: {
        component: SPFieldUserDisplay_1.default
    },
    UserMulti: {
        component: SPFieldUserDisplay_1.default
    },
    URL: {
        component: SPFieldUrlDisplay_1.default
    },
    File: {
        component: SPFieldTextDisplay_1.default
    },
    TaxonomyFieldType: {
        component: SPFieldTextDisplay_1.default,
        valuePreProcess: function (val) { return (val ? val.Label : ''); }
    },
    TaxonomyFieldTypeMulti: {
        component: SPFieldTextDisplay_1.default,
        valuePreProcess: function (val) { return (val ? val.map(function (v) { return v.Label; }).join(', ') : ''); }
    }
    /* The following are known but unsupported types as of now:
  Attachments: null,
  */
};
var SPFormField = function (props) {
    var fieldControl = null;
    var fieldType = props.fieldSchema.FieldType;
    if (props.controlMode === ControlMode_1.ControlMode.Display) {
        if (DisplayFieldTypeMappings.hasOwnProperty(fieldType)) {
            var fieldMapping = DisplayFieldTypeMappings[fieldType];
            var childProps = fieldMapping.valuePreProcess
                ? __assign({}, props, { value: fieldMapping.valuePreProcess(props.value) }) : props;
            fieldControl = React.createElement(fieldMapping.component, childProps);
        }
        else if (!props.hideIfFieldUnsupported) {
            var value = props.value
                ? typeof props.value === 'string' ? props.value : JSON.stringify(props.value)
                : '';
            fieldControl = (React.createElement("div", { className: "ard-" + fieldType + "field-display" },
                React.createElement("span", null, value),
                React.createElement("div", { className: styles.unsupportedFieldMessage },
                    React.createElement(Icon_1.Icon, { iconName: "Error" }),
                    " ", "\"Unsupported field type\" \"" + fieldType + "\"")));
        }
    }
    else {
        if (EditFieldTypeMappings.hasOwnProperty(fieldType)) {
            fieldControl = React.createElement(EditFieldTypeMappings[fieldType], props);
        }
        else if (!props.hideIfFieldUnsupported) {
            var isObjValue = props.value && typeof props.value !== 'string';
            var value = props.value
                ? typeof props.value === 'string' ? props.value : JSON.stringify(props.value)
                : '';
            fieldControl = (React.createElement(TextField_1.TextField, { multiline: isObjValue, value: value, errorMessage: "\"Unsupported field type\" \"" + fieldType + "\"" }));
        }
    }
    return fieldControl ? (React.createElement(FormField_1.default, __assign({}, props, { label: props.label || props.fieldSchema.Title, description: props.description || props.fieldSchema.Description, required: props.fieldSchema.Required, errorMessage: props.errorMessage }), fieldControl)) : null;
};
exports.default = SPFormField;
