"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Link_1 = require("office-ui-fabric-react/lib/Link");
var FileTypeIcon_1 = require("./fileTypeIcon/FileTypeIcon");
var IFileTypeIcon_1 = require("./fileTypeIcon/IFileTypeIcon");
var React = require("react");
var SPViewFields = /** @class */ (function () {
    function SPViewFields() {
    }
    SPViewFields.GenerateColumn = function (fieldSchema, columnClickHandler) {
        var column;
        switch (fieldSchema.FieldType) {
            case 'Computed':
                column = this.GenerateColumnComputed(fieldSchema, columnClickHandler);
                break;
            case 'DateTime':
                column = this.GenerateColumnDate(fieldSchema, columnClickHandler);
                break;
            case 'User':
                column = this.GenerateColumnUser(fieldSchema, columnClickHandler);
                break;
            case 'Note':
                column = this.GenerateColumnString(fieldSchema, columnClickHandler);
                break;
            case 'Text':
                column = this.GenerateColumnString(fieldSchema, columnClickHandler);
                break;
            case 'Choice':
                column = this.GenerateColumnString(fieldSchema, columnClickHandler);
                break;
            case 'Number':
                column = this.GenerateColumnNumber(fieldSchema, columnClickHandler);
                break;
            case 'Currency':
                column = this.GenerateColumnCurrency(fieldSchema, columnClickHandler);
                break;
            case 'Lookup':
                column = this.GenerateColumnLookup(fieldSchema, columnClickHandler);
                break;
            case 'Boolean':
                column = this.GenerateColumnString(fieldSchema, columnClickHandler);
                break;
            case 'URL':
                column = this.GenerateColumnUrl(fieldSchema, columnClickHandler);
                break;
            case 'OutcomeChoice':
                column = this.GenerateColumnString(fieldSchema, columnClickHandler);
                break;
            case 'TaxonomyFieldType':
                column = this.GenerateColumnString(fieldSchema, columnClickHandler);
                break;
            default:
                column = this.GenerateColumnString(fieldSchema, columnClickHandler);
                break;
        }
        return column;
    };
    SPViewFields.GenerateColumnText = function (fieldSchema, columnClickHandler) {
        return {
            key: fieldSchema.ID,
            name: fieldSchema.DisplayName,
            fieldName: fieldSchema.RealFieldName,
            minWidth: 70,
            maxWidth: 350,
            isRowHeader: true,
            isResizable: true,
            isSorted: false,
            onColumnClick: columnClickHandler,
            isSortedDescending: false,
            sortAscendingAriaLabel: 'Sorted A to Z',
            sortDescendingAriaLabel: 'Sorted Z to A',
            data: 'string',
            isPadded: true
        };
    };
    SPViewFields.GenerateColumnString = function (fieldSchema, columnClickHandler) {
        return {
            key: fieldSchema.ID,
            name: fieldSchema.DisplayName,
            fieldName: fieldSchema.RealFieldName,
            minWidth: 70,
            maxWidth: 120,
            isRowHeader: true,
            onColumnClick: columnClickHandler,
            isResizable: true,
            isSorted: false,
            isSortedDescending: false,
            data: 'string',
            isPadded: true,
            onRender: function (item) {
                var fieldName = fieldSchema.RealFieldName;
                return React.createElement("span", null, item[fieldName]);
            }
        };
    };
    SPViewFields.GenerateColumnComputed = function (fieldSchema, columnClickHandler) {
        if (fieldSchema.RealFieldName === 'DocIcon') {
            return {
                key: fieldSchema.ID,
                name: fieldSchema.DisplayName,
                fieldName: fieldSchema.RealFieldName,
                iconName: 'Page',
                isIconOnly: true,
                minWidth: 16,
                maxWidth: 16,
                onColumnClick: columnClickHandler,
                onRender: function (item) {
                    var docUrl = item.FileRef;
                    return React.createElement(FileTypeIcon_1.FileTypeIcon, { type: IFileTypeIcon_1.IconType.image, path: docUrl });
                }
            };
        }
        else {
            return {
                key: fieldSchema.ID,
                name: fieldSchema.DisplayName,
                fieldName: fieldSchema.RealFieldName,
                minWidth: 100,
                maxWidth: 150,
                isRowHeader: true,
                onColumnClick: columnClickHandler,
                isResizable: true,
                isSorted: false,
                isSortedDescending: false,
                data: 'string',
                isPadded: true,
                onRender: function (item) {
                    var fieldName = fieldSchema.RealFieldName;
                    return React.createElement("span", null, item[fieldName]);
                }
            };
        }
    };
    SPViewFields.GenerateColumnLookup = function (fieldSchema, columnClickHandler) {
        return {
            key: fieldSchema.ID,
            name: fieldSchema.DisplayName,
            fieldName: fieldSchema.RealFieldName,
            minWidth: 70,
            maxWidth: 120,
            isRowHeader: true,
            isResizable: true,
            onColumnClick: columnClickHandler,
            isSorted: false,
            isSortedDescending: false,
            data: 'string',
            isPadded: true,
            onRender: function (item) {
                return React.createElement("span", null, '');
            }
        };
    };
    SPViewFields.GenerateColumnUrl = function (fieldSchema, columnClickHandler) {
        return {
            key: fieldSchema.ID,
            name: fieldSchema.DisplayName,
            fieldName: fieldSchema.RealFieldName,
            minWidth: 70,
            maxWidth: 120,
            isRowHeader: true,
            onColumnClick: columnClickHandler,
            isResizable: true,
            isSorted: false,
            isSortedDescending: false,
            data: 'Url',
            isPadded: true,
            onRender: function (item) {
                var fieldName = fieldSchema.RealFieldName;
                return React.createElement(Link_1.Link, { href: "" + item[fieldName] }, item[fieldName]);
            }
        };
    };
    SPViewFields.GenerateColumnUser = function (fieldSchema, columnClickHandler) {
        return {
            key: fieldSchema.ID,
            name: fieldSchema.DisplayName,
            fieldName: fieldSchema.RealFieldName,
            minWidth: 70,
            maxWidth: 90,
            isRowHeader: true,
            isResizable: true,
            onColumnClick: columnClickHandler,
            isSorted: false,
            isSortedDescending: false,
            data: 'string',
            isPadded: true,
            onRender: function (item) {
                var fieldName = fieldSchema.RealFieldName;
                var user = item[fieldName];
                return React.createElement("span", null, user[0].title);
            }
        };
    };
    SPViewFields.GenerateColumnCurrency = function (fieldSchema, columnClickHandler) {
        return {
            key: fieldSchema.ID,
            name: fieldSchema.DisplayName,
            fieldName: fieldSchema.RealFieldName,
            minWidth: 70,
            maxWidth: 90,
            isRowHeader: true,
            isResizable: true,
            onColumnClick: columnClickHandler,
            isSorted: false,
            isSortedDescending: false,
            data: 'string',
            isPadded: true,
            onRender: function (item) {
                var fieldName = fieldSchema.RealFieldName;
                return React.createElement("span", null, item[fieldName]);
            }
        };
    };
    SPViewFields.GenerateColumnDate = function (fieldSchema, columnClickHandler) {
        return {
            key: fieldSchema.ID,
            name: fieldSchema.DisplayName,
            fieldName: fieldSchema.RealFieldName,
            minWidth: 70,
            maxWidth: 90,
            isRowHeader: true,
            isResizable: true,
            onColumnClick: columnClickHandler,
            isSorted: false,
            isSortedDescending: false,
            data: 'number',
            isPadded: true,
            onRender: function (item) {
                var fieldName = fieldSchema.RealFieldName;
                return React.createElement("span", null, item[fieldName]);
            }
        };
    };
    SPViewFields.GenerateColumnNumber = function (fieldSchema, columnClickHandler) {
        return {
            key: fieldSchema.ID,
            name: fieldSchema.DisplayName,
            fieldName: fieldSchema.RealFieldName,
            minWidth: 70,
            maxWidth: 90,
            onColumnClick: columnClickHandler,
            isResizable: true,
            isCollapsable: true,
            data: 'number',
            onRender: function (item) {
                var fieldName = fieldSchema.RealFieldName;
                return React.createElement("span", null, item[fieldName]);
            }
        };
    };
    return SPViewFields;
}());
exports.SPViewFields = SPViewFields;
