"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var sp_lodash_subset_1 = require("@microsoft/sp-lodash-subset");
var IFileTypeIcon_1 = require("./IFileTypeIcon");
var Icon_1 = require("office-ui-fabric-react/lib/components/Icon");
require("../FileTypeIcon.module.scss");
var ICON_GENERIC = 'Page';
var ICON_DEFAULT_SIZE = 'icon16';
/**
 * File type icon component
 */
var FileTypeIcon = /** @class */ (function (_super) {
    __extends(FileTypeIcon, _super);
    function FileTypeIcon(props) {
        return _super.call(this, props) || this;
    }
    /**
     * Default React component render method
     */
    FileTypeIcon.prototype.render = function () {
        var iconElm = React.createElement("span", null);
        // Check the type of icon that needs to be displayed
        if (this.props.type === IFileTypeIcon_1.IconType.image) {
            // Return an image icon element
            var iconImage = this._getIconImageName();
            // Check if the image was found, otherwise a generic image will be returned
            if (typeof iconImage.image !== 'undefined' && iconImage.image !== null) {
                iconElm = (React.createElement(Icon_1.Icon, { iconType: Icon_1.IconType.image, imageProps: {
                        className: "ms-BrandIcon--" + iconImage.size + " ms-BrandIcon--" + iconImage.image
                    } }));
            }
            else {
                // Return a generic image
                var imgElm = React.createElement("img", null);
                // Check the size of the generic image which has to be returned
                switch (iconImage.size) {
                    case 'icon16':
                        imgElm = (React.createElement(Icon_1.Icon, { iconType: Icon_1.IconType.image, imageProps: {
                                src: IFileTypeIcon_1.ICON_GENERIC_16
                            } }));
                        break;
                    case 'icon48':
                        imgElm = (React.createElement(Icon_1.Icon, { iconType: Icon_1.IconType.image, imageProps: {
                                src: IFileTypeIcon_1.ICON_GENERIC_48
                            } }));
                        break;
                    case 'icon96':
                        imgElm = (React.createElement(Icon_1.Icon, { iconType: Icon_1.IconType.image, imageProps: {
                                src: IFileTypeIcon_1.ICON_GENERIC_96
                            } }));
                        break;
                    default:
                        imgElm = (React.createElement(Icon_1.Icon, { iconType: Icon_1.IconType.image, imageProps: {
                                src: IFileTypeIcon_1.ICON_GENERIC_16
                            } }));
                        break;
                }
                iconElm = (React.createElement("div", { style: {
                        display: 'inline-block'
                    } }, imgElm));
            }
        }
        else {
            // Return the icon font element
            var iconClass = this._getIconClassName();
            iconElm = React.createElement(Icon_1.Icon, { iconName: iconClass });
        }
        // Return the icon element
        return iconElm;
    };
    /**
  * Function which returns the font icon
  */
    FileTypeIcon.prototype._getIconClassName = function () {
        var className = ICON_GENERIC;
        // Check if the path property is provided
        if (typeof this.props.path !== 'undefined' && this.props.path !== null) {
            var path = this.props.path;
            var fileExtension = this._getFileExtension(path);
            // Check the known file extensions list
            var iconName = this._getIconByExtension(fileExtension.toLowerCase(), IFileTypeIcon_1.IconType.font);
            if (iconName !== null) {
                className = iconName;
            }
        }
        else if (typeof this.props.application !== 'undefined' && this.props.application !== null) {
            // Check if the application name has been provided
            var application = this.props.application;
            var iconName = this._getIconByApplicationType(application, IFileTypeIcon_1.IconType.font);
            if (iconName !== null) {
                className = iconName;
            }
        }
        return className;
    };
    /**
     * Function which returns the image icon
     */
    FileTypeIcon.prototype._getIconImageName = function () {
        var size = ICON_DEFAULT_SIZE;
        var image = null;
        // Get the right icon size to display
        if (typeof this.props.size !== 'undefined' && this.props.size !== null) {
            // Retrieve the right icon size
            size = this._getFileSizeName(this.props.size);
        }
        // Check if the path is provided
        if (typeof this.props.path !== 'undefined' && this.props.path !== null) {
            var path = this.props.path;
            var fileExtension = this._getFileExtension(path);
            // Get the image for the current file extension
            image = this._getIconByExtension(fileExtension.toLowerCase(), IFileTypeIcon_1.IconType.image);
        }
        else if (typeof this.props.application !== 'undefined' && this.props.application !== null) {
            // Check if the application name has been provided
            var application = this.props.application;
            image = this._getIconByApplicationType(application, IFileTypeIcon_1.IconType.image);
        }
        return { size: size, image: image };
    };
    /**
  * Function to retrieve the file extension from the path
  *
  * @param value File path
  */
    FileTypeIcon.prototype._getFileExtension = function (value) {
        // Split the URL on the dots
        var splittedValue = value.split('.');
        // Take the last value
        var extensionValue = splittedValue.pop();
        // Check if there are query string params in place
        if (extensionValue.indexOf('?') !== -1) {
            // Split the string on the question mark and return the first part
            var querySplit = extensionValue.split('?');
            extensionValue = querySplit[0];
        }
        return extensionValue;
    };
    /**
  * Find the icon name for the provided extension
  *
  * @param extension File extension
  */
    FileTypeIcon.prototype._getIconByExtension = function (extension, iconType) {
        // Find the application index by the provided extension
        var appIdx = sp_lodash_subset_1.findIndex(IFileTypeIcon_1.ApplicationIconList, function (item) {
            return item.extensions.indexOf(extension.toLowerCase()) !== -1;
        });
        // Check if an application has found
        if (appIdx !== -1) {
            // Check the type of icon, the image needs to get checked for the name
            if (iconType === IFileTypeIcon_1.IconType.font) {
                return IFileTypeIcon_1.ApplicationIconList[appIdx].iconName;
            }
            else {
                var knownImgs = IFileTypeIcon_1.ApplicationIconList[appIdx].imageName;
                // Check if the file extension is known
                var imgIdx = knownImgs.indexOf(extension);
                if (imgIdx !== -1) {
                    return knownImgs[imgIdx];
                }
                else {
                    // Return the first one if it was not known
                    return knownImgs[0];
                }
            }
        }
        return null;
    };
    /**
  * Find the icon name for the application
  *
  * @param application
  */
    FileTypeIcon.prototype._getIconByApplicationType = function (application, iconType) {
        // Find the application index by the provided extension
        var appIdx = sp_lodash_subset_1.findIndex(IFileTypeIcon_1.ApplicationIconList, function (item) { return item.application === application; });
        // Check if an application has found
        if (appIdx !== -1) {
            var knownApp = IFileTypeIcon_1.ApplicationIconList[appIdx];
            if (iconType === IFileTypeIcon_1.IconType.font) {
                return knownApp.iconName;
            }
            else {
                // Check if the application has a known list of image types
                if (knownApp.imageName.length > 0) {
                    return knownApp.imageName[0];
                }
            }
        }
        return null;
    };
    /**
  * Return the right image size for the provided value
  *
  * @param value Image size value
  */
    FileTypeIcon.prototype._getFileSizeName = function (value) {
        // Find the image size index by the image size
        var sizeIdx = sp_lodash_subset_1.findIndex(IFileTypeIcon_1.IconSizes, function (size) { return size.size === value; });
        // Check if an icon size has been retrieved
        if (sizeIdx !== -1) {
            // Return the first icon size
            return IFileTypeIcon_1.IconSizes[sizeIdx].name;
        }
        // Return the default file size if nothing was found
        return ICON_DEFAULT_SIZE;
    };
    return FileTypeIcon;
}(React.Component));
exports.FileTypeIcon = FileTypeIcon;
