/**
 * Available icon types
 */
export declare enum IconType {
    font = 1,
    image = 2
}
/**
 * Available applications / types
 */
export declare enum ApplicationType {
    Access = 1,
    ASPX = 2,
    Code = 3,
    CSS = 4,
    CSV = 5,
    Excel = 6,
    HTML = 7,
    Image = 8,
    Mail = 9,
    OneNote = 10,
    PDF = 11,
    PowerApps = 12,
    PowerPoint = 13,
    Project = 14,
    Publisher = 15,
    SASS = 16,
    Visio = 17,
    Word = 18
}
/**
 * Available image sizes
 */
export declare enum ImageSize {
    small = 1,
    medium = 2,
    large = 3
}
/**
 * Interface for the application icons list
 */
export interface IApplicationIcons {
    application: ApplicationType;
    extensions: string[];
    iconName: string;
    imageName: string[];
}
/**
 * Array with all the known applications and their icon and image names
 */
export declare const ApplicationIconList: IApplicationIcons[];
/**
 * Array with the known icon image sizes
 */
export declare const IconSizes: {
    size: ImageSize;
    name: string;
}[];
/**
 * Interface for the image result when return the image instead of the icon font
 */
export interface IImageResult {
    size: string;
    image: string;
}
/**
 * Interface for the FileTypeIcon component properties
 */
export interface IFileTypeIconProps {
    type: IconType;
    application?: ApplicationType;
    path?: string;
    size?: ImageSize;
}
/**
 * Generic file type icons base64 encoded
 */
export declare const ICON_GENERIC_16: string;
export declare const ICON_GENERIC_48: string;
export declare const ICON_GENERIC_96: string;
