"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Available icon types
 */
var IconType;
(function (IconType) {
    IconType[IconType["font"] = 1] = "font";
    IconType[IconType["image"] = 2] = "image";
})(IconType = exports.IconType || (exports.IconType = {}));
/**
 * Available applications / types
 */
var ApplicationType;
(function (ApplicationType) {
    ApplicationType[ApplicationType["Access"] = 1] = "Access";
    ApplicationType[ApplicationType["ASPX"] = 2] = "ASPX";
    ApplicationType[ApplicationType["Code"] = 3] = "Code";
    ApplicationType[ApplicationType["CSS"] = 4] = "CSS";
    ApplicationType[ApplicationType["CSV"] = 5] = "CSV";
    ApplicationType[ApplicationType["Excel"] = 6] = "Excel";
    ApplicationType[ApplicationType["HTML"] = 7] = "HTML";
    ApplicationType[ApplicationType["Image"] = 8] = "Image";
    ApplicationType[ApplicationType["Mail"] = 9] = "Mail";
    ApplicationType[ApplicationType["OneNote"] = 10] = "OneNote";
    ApplicationType[ApplicationType["PDF"] = 11] = "PDF";
    ApplicationType[ApplicationType["PowerApps"] = 12] = "PowerApps";
    ApplicationType[ApplicationType["PowerPoint"] = 13] = "PowerPoint";
    ApplicationType[ApplicationType["Project"] = 14] = "Project";
    ApplicationType[ApplicationType["Publisher"] = 15] = "Publisher";
    ApplicationType[ApplicationType["SASS"] = 16] = "SASS";
    ApplicationType[ApplicationType["Visio"] = 17] = "Visio";
    ApplicationType[ApplicationType["Word"] = 18] = "Word";
})(ApplicationType = exports.ApplicationType || (exports.ApplicationType = {}));
/**
 * Available image sizes
 */
var ImageSize;
(function (ImageSize) {
    ImageSize[ImageSize["small"] = 1] = "small";
    ImageSize[ImageSize["medium"] = 2] = "medium";
    ImageSize[ImageSize["large"] = 3] = "large";
})(ImageSize = exports.ImageSize || (exports.ImageSize = {}));
/**
 * Array with all the known applications and their icon and image names
 */
exports.ApplicationIconList = [
    {
        application: ApplicationType.Access,
        extensions: [
            'accdb', 'accde', 'accdt', 'accdr', 'mdb'
        ],
        iconName: 'AccessLogo',
        imageName: ['accdb']
    }, {
        application: ApplicationType.ASPX,
        extensions: [
            'aspx', 'master'
        ],
        iconName: 'FileASPX',
        imageName: []
    }, {
        application: ApplicationType.Code,
        extensions: [
            'js', 'ts', 'cs'
        ],
        iconName: 'FileCode',
        imageName: []
    }, {
        application: ApplicationType.CSS,
        extensions: ['css'],
        iconName: 'FileCSS',
        imageName: []
    }, {
        application: ApplicationType.CSV,
        extensions: ['csv'],
        iconName: 'ExcelDocument',
        imageName: ['csv']
    }, {
        application: ApplicationType.Excel,
        extensions: [
            'xls',
            'xlt',
            'xlm',
            'xlsx',
            'xlsm',
            'xltx',
            'xltm',
            'ods'
        ],
        iconName: 'ExcelDocument',
        imageName: ['xlsx', 'xls', 'xltx', 'ods']
    }, {
        application: ApplicationType.HTML,
        extensions: ['html'],
        iconName: 'FileHTML',
        imageName: []
    }, {
        application: ApplicationType.Image,
        extensions: [
            'jpg', 'jpeg', 'gif', 'png'
        ],
        iconName: 'FileImage',
        imageName: []
    }, {
        application: ApplicationType.Mail,
        extensions: ['msg'],
        iconName: 'Mail',
        imageName: []
    }, {
        application: ApplicationType.OneNote,
        extensions: [
            'one', 'onepkg', 'onetoc'
        ],
        iconName: 'OneNoteLogo',
        imageName: ['one', 'onepkg', 'onetoc']
    }, {
        application: ApplicationType.PDF,
        extensions: ['pdf'],
        iconName: 'PDF',
        imageName: []
    }, {
        application: ApplicationType.PowerApps,
        extensions: ['msapp'],
        iconName: 'PowerApps',
        imageName: []
    }, {
        application: ApplicationType.PowerPoint,
        extensions: [
            'ppt',
            'pot',
            'pps',
            'pptx',
            'pptm',
            'potx',
            'potm',
            'ppam',
            'ppsx',
            'ppsm',
            'sldx',
            'sldx'
        ],
        iconName: 'PowerPointDocument',
        imageName: ['odp', 'potx', 'ppsx', 'pptx']
    }, {
        application: ApplicationType.Project,
        extensions: [
            'mpp', 'mpt', 'mpx', 'mpd'
        ],
        iconName: 'ProjectLogoInverse',
        imageName: ['mpp', 'mpt']
    }, {
        application: ApplicationType.Publisher,
        extensions: ['pub'],
        iconName: 'PublisherLogo',
        imageName: ['pub']
    }, {
        application: ApplicationType.SASS,
        extensions: [
            'scss', 'sass'
        ],
        iconName: 'FileSass',
        imageName: []
    }, {
        application: ApplicationType.Visio,
        extensions: [
            'vsd',
            'vss',
            'vst',
            'vdx',
            'vsx',
            'vtx',
            'vsdx'
        ],
        iconName: 'VisioDocument',
        imageName: ['vsdx', 'vssx', 'vstx']
    }, {
        application: ApplicationType.Word,
        extensions: [
            'doc',
            'dot',
            'docx',
            'docm',
            'dotx',
            'dotm',
            'docb',
            'odt'
        ],
        iconName: 'WordDocument',
        imageName: ['docx', 'dotx', 'odt']
    }
];
/**
 * Array with the known icon image sizes
 */
exports.IconSizes = [
    {
        size: ImageSize.small,
        name: 'icon16'
    }, {
        size: ImageSize.medium,
        name: 'icon48'
    }, {
        size: ImageSize.large,
        name: 'icon96'
    }
];
/**
 * Generic file type icons base64 encoded
 */
exports.ICON_GENERIC_16 = 
// tslint:disable-next-line:max-line-length
'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAMAAAAoLQ9TAAAAIGNIUk0AAH' +
    'omAACAhAAA+gAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAACxUExURf///6CgoZeYmJ+goJSVlpydna' +
    'ampqWlpaOjo6KioqCgoZ+fn52enpycnJqbm/39/fz9/fz8/dzc3Pr7+/r6+/n6+vn5+vj5+vj4+erq6o' +
    'yMjJGSk/n6+/f4+fv8/JCRkvj5+Y+QkPv7/I2Oj/f4+IyNjvb3+IqMjJmZmvz8/ImKi5eYmPf3+IeJip' +
    'aXl/X294aHiJSVlvb394SGh5OUlPb294OFhZKTk4GDhICCg////6edRp4AAAAGdFJOUwD5MPww+XxQO+' +
    'MAAAABYktHRACIBR1IAAAAsElEQVQY0z3L2RqCIBCGYdq0MkPCgqxxQaI9LFvs/m8smIP+s++dZwghQT' +
    'ieTKNZPO/1CS6klCaMsWAxGCKMKU+XKyGD9WKEMKGpBxFk2QZhStPl1gFAXiBEiW9ZSsgrhBlzZwluqk' +
    'aImVgJKAG02iHMmRAuQRu1RzgcSyl9G3VCOOf+/2KM4VeEW661T2N5g3BXvszDWt4iPD28rBt/I3z4fx' +
    '1CUdW7/enatO/uS8gP83oU3WB3gUcAAAAASUVORK5CYII=';
exports.ICON_GENERIC_48 = 
// tslint:disable-next-line:max-line-length
'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAADAAAAAwCAMAAABg3Am1AAAAIGNIUk0AAH' +
    'omAACAhAAA+gAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAGeUExURf///6Kio5iZmaSkpZeYmKOjpJ' +
    'aXl6ChopWWlp+goZSVlZ6en5OTlJucnZGSk5qbm6ampqWlpaSkpaSkpKOjo6KioqGioqGhoaCgoJ+goJ' +
    '+fn56fn56enp2enp2dnZydnZycnJubnJqbm5qam5mamv39/fz9/fz8/fz9/Pz8/Pv8/P3+/unp6fv7+/' +
    'r7+/r6+/r6+vn6+vn6+/n5+vj5+vj4+ff4+fj5+fLy8unq6vT09PHx8ejp6fv7/PPz8+/v7+Xl5e3t7e' +
    'vr6+Hh4e7u7ufn597e3vn6+erq6ujo6OPj49ra2vn5+YyMjJCSkuLi497f4N7f397e393e3+Hh4pCRkf' +
    'f4+Pf3+Pb3+I+QkY+QkI6PkI6Pj42Oj4yOjoyNjouNjYuMjYqMjIqLjImLi4mKi/b294iKipmZmvX294' +
    'eJipiZmfb394eIiZiYmYaIiZeYmIaHiJeXmIWHiJaXl4WGh5WWl4SGh5WWloSFhpSVloOFhpSVlYKEhZ' +
    'OUlZOTlIKDhJKTlIGDhJKTk4CCg5GSkn+Bgn+BgX6Agf///0viRIgAAAAQdFJOUwD5MPww/DD8MPww/D' +
    'D7MPl5g3acAAAAAWJLR0QAiAUdSAAAAmRJREFUSMfN0Wdf01AUwOG6twYolL3T2NjeEpMmao1AHTgq1k' +
    'Eb9i4Gi4iIiFhFrODH9o4kve1J+5rz+v+cc/NLIHByRxAaGpuCweaWUKi1rb2js6u7p7evf2Dw1OlaQH' +
    'QmjEeSbkpSRJIjt4TombP+oEGMxRCKx+NDinJbVRVNS2i6IQt37p477wsaMWCCBxHhXvL+hYt+oEk0Ad' +
    'AweJAcHrl02QcE6ZOqL8hCcng09fDK1VqA+waVgUejqejjJ9euA9Assv34AAFjLkg9jT4bef7iBgAtIu' +
    'vxAUVVVUNLM/CSzTgAITEeLx9wvtlIvMpkMq/fvH03UQMMsd59kZHQ8WRzljkJQKvIcvdAWsNA98AUAG' +
    '1hheW41wxygLzIA9MAtIfd9ao2Rr+AO2CZMwB0hNl21qfZF5TBLACdkspGMWiPH+QcoGAOgC4GFLye9u' +
    'RB3gHLnAegW9LwJ5BcTdDeexAFCwD0SBodlawv9+yAZS4C0Cux2llf2VvmEgB9kUSC1pW9C5YB6HeeRH' +
    'O9qrdiKwAMEKCTmuRVvYVWARiMGGy8nOvzaA2A9wTopHZyvrfROgAf2Ee7Nd8XbBttAPBR1vnJsh9Gx8' +
    'ZgE4BPckXO9XkCtgD4LPvntLfRNgBfZK4u5wXa22gHgK9ylk6Oz9l6AnYB+GbmcpUx19toD4DvplU9Ba' +
    '+30T4AP8zaOQZFAH6atXNf8IsH+cocgwMAfpve7uqagEMA/sTydGzfQSUA/iK7zviA8frgCIAJVHeOAZ' +
    'icmp6ZnZtfWFxaXlldW9/Y3Nre2d3bLxYPDkulo+N/gZM7/wGRlGTTsm+SowAAAABJRU5ErkJggg==';
exports.ICON_GENERIC_96 = 
// tslint:disable-next-line:max-line-length
'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAGAAAABgCAMAAADVRocKAAAAIGNIUk0AAH' +
    'omAACAhAAA+gAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAIoUExURf///5+goJmamp+foJmZmp6fn5' +
    'iZmZiYmZ2enpeYmJ2dnpaXmJydnZaXl5ycnZWWl5ucnJWVlpqbnJSVlZqbm5mam5OUlJmampOTlJiZmp' +
    'KTk5iZmZGSk5eYmZGSkpaYmJCRkpaXmKampqWlpaSkpaSkpKOkpKOjo6Kio6KioqGioqGhoaChoaCgoa' +
    'CgoJ+goJ+foJ+fn56fn56en56enp2enp2dnp2dnZydnZycnJucnJubnJubm5qbm5qam/39/fz9/fz8/f' +
    'z9/Pz8/Pv8/P7+/vLy8tjY2Pv7+/r7+/r6+/r6+vn6+vn6+/n5+vn6+fj5+vj4+ff4+fj5+dfY2Pn5+d' +
    'fX2NfX1/v7/NbX19bW19bW1tXW1tXV1tXV1ZCRkYyMjI+Qkejo6d/f4N7f4N7f397e393e3+Hh4vDw8e' +
    'vr7Orr7Orr6+rq6+nq6+7u7/f4+Pf3+Pb3+I+QkI6QkI6PkI6Pj42Pj42Oj42OjoyOjoyNjouNjYuMjY' +
    'qMjIqLjPb394mLi/b294mKi/X294iKi5mamoiKioiJipmZmoeJipiZmYeIiYaIiZiYmYaIiJeYmIaHiJ' +
    'eXmIWHiJaXmIWHh5aXl4WGh5aWl4SGh5WWl4SGhpWWloSFhpWVloOFhpSVlpSVlYOFhYOEhYKEhZOUlZ' +
    'OUlIKDhJOTlIGDhJKTlJKTk4GDg4CCg5GSk5GSkoCBgpCSkn+BgpCRkn+BgX6AgX1/gP///4uaePMAAA' +
    'AidFJOUwDeEN4Q3hAQ3hDeEN4Q3hDeEN4Q3t0Q3RDdEN0Q3RDdEN2/iv+3AAAAAWJLR0QAiAUdSAAABK' +
    'pJREFUaN7t1Ot/01QYwHG8oOAdxPu9Y5RtMGDAGIPRloaQsDRLU6ZBFESEeRmzC7fB2IUuyIThRISJiF' +
    'OYzglTnMy/z1zbc5Jz8py08/PxxZ4Xffn75jkn6YIF8zM/cz+xWKyqqmp5dfWKeDy+sqamtraubtXq+v' +
    'o1a9c1NKzfsLGxcVNT0+bm5i1bW1q2PfBgGUDCP0lnUuYkt1u/6bT5w6V3xPidDz1cBiAIgmjPLntaJW' +
    'syGdkcqU1RFDmbNX/VXDrG8zsXPhIVqLIAl3AEyREsQPED/O6Fj5YHCIEVbECygHYE4N9etHgOAVnK+Q' +
    'H+nccejwQsTwgafkbYJZiAggP8nieejAJUJzRNw1aAAH7PU09HBKJtwPPvPrOEHVhBu4MM5Q6s2bv0WW' +
    'YgHv4WkQF+7zJmIR76HUj+76AoPPd8FAD9klEg8CUjwgsvsgErE6I3DH8VqPDSy0xATQLvewuUgHYywL' +
    '/3yqtRADfvLoDcsQOoQYB//7XXGYDaBJonLOCdUBDg973xJguwCx1JQv+JAIDf9xYM1GFAK7oAckIUgN' +
    '8fEcD62AI28EFgDsDAqoQ/T1kgp3548OBH7hw6dPhwR0fHxwzAag9o9fXdBez/CQfIfvLpZ850dnYeOd' +
    'LV1fU5A1CfwOt4H1kgl81mVXfy+e5u3RztKAOQlPBx+84BycgJkYBjMLAmSezjC1CB4zCwNonnsb7zCl' +
    'EX0LUTMLAuScibfd8BUYCTMNCQRPLEPmGBItDDCGQySN28X7uvIH3yAkzA+iRet/uK2yfeMAqcgoENKR' +
    'kbRaL0CQvo2mkY2IgDkns8Xj94QBjQCwONKfzpnbwc3i8LMOtentAnvEIWcAYGNnmvaVtbIO/2qQvoWh' +
    '8MNG1vsybnxuE+sgAbkFLQke080scvQMX6TMBmFJDbkTytjwL9MNCcKj27XXfybl/197EFGAHZSre7dS' +
    'wP9XVtAAa2pLOlUbx86XiQvv+AdF1gALamsTaSh/uDwlkYaMHfIiQf7PsOSC8IQxEB1ZcP7w8WRAZgW6' +
    'qY9uKkvNP3LWCI52DgC07F48U82DeB8wxAOocPKU/qDxYMQxyGgS/TWNyt43laPxJgh7LEPKlvHZAJXI' +
    'CBixyWJucpfUMcYQDQLzlYJz++248KqIQhPr5zARZwCQa+4tSQCe8b4igMfM2BeWq/QoCSR/qGeBkGvu' +
    'HC82F9Q7wCA99ylDr58bG+IV6FgWscvR7M431DHIsM5EPzvj4T8B2HlYt1Ut77vkrAdRj4nsvnA3FiPd' +
    'g3xBsw8AOHp6l183j8fUO8CQM/at3o6NQJ5k1gHAZ+0sA05fEZgZ81nWGIeRO4NTfAIKVviLfnAqDmTW' +
    'ACBn7Rys6zAb9qZedNYLIyoBCeZwN+0+gPD+RNYAoGftdodTDPBtzRiHGGugXcjQg4bba4DUzDwB9CAR' +
    '3mdlQgWjgK8KdYXtsB7sHAXxUBMzDw9/8buA8D+ysCZmHgwH8PVDIswNFjx0+c7Ok5dbq390xfX19//8' +
    'DA2aGhc+eHhy+MjFwaHb185erY2PUbN8fHb92emJicnJq6Oz09fW9m5v7s7Ow/MDA/8xN1/gVe/atO93' +
    'sFBAAAAABJRU5ErkJggg==';
